sleep

Function sleep 

pub async fn sleep(duration: Duration)
Sleep for duration using the native or browser timer backend of timeout.

Panics

May panic if the timer cannot represent the deadline for duration.